@@ -2,6 +2,8 @@
 import pytest
 import pkg_resources
 
+from ubermag.basic_logging import setup_logging
+
 __version__ = pkg_resources.get_distribution(__name__).version
 
 
@@ -20,5 +22,5 @@ def test():
     return pytest.main(['-m', 'not travis and not docker',
                         '-v', '--pyargs', 'ubermagutil', 'discretisedfield',
                         'ubermagtable', 'micromagneticmodel', 'oommfc',
-                        'micromagnetictests', 'micromagneticdata',
+                        'micromagnetictests', 'micromagneticdata', 'mag2exp',
                         'ubermag', '-l'])  # pragma: no cover
